@@ -1,5 +1,6 @@
 from . import basic
 from . import misc
+from . import pooling
 
 from .Inception import Inception
 from .InceptionMerge import InceptionMerge
@@ -8,5 +9,4 @@ from .MinibatchDiscrimination import MinibatchDiscrimination
 from .Reshape import Reshape
 
 from .TemporalConcatenation import TemporalConcatenation
-from .BiFPN import BiFPN
 from .DepthwiseSeparableConvolution import DepthwiseSeparableConvolution
